==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x0ec7+ 5029-0x2244)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x102c+ 3775-0x1eea)))){(@arr=split ( /:/ ,$buffer,(0x0783+ 7950-0x2691)));(
@result=splice (@arr,(0x01a6+ 3242-0x0e50),(0x0def+ 2592-0x180d)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x06cf+ 2049-0x0ae8))+($microseconds/(0x07dd+ 2794-0x0edf))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x151d+ 1586-0x1b27)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval
!=(-(0x1a1c+ 1416-0x1fa3)))){(@arr=split ( /:/ ,$buffer,(0x016a+ 7874-0x202c)));
(@result=splice (@arr,(0x0361+ 3059-0x0f54),(0x0932+ 7250-0x257b)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0332+ 8571-0x2485)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x05ec+ 4223-0x166a)))){(@arr=split ( /:/ ,$buffer,
(0x0851+ 2494-0x120f)));(@result=splice (@arr,(0x0bf0+ 6478-0x253e),
(0x0c0f+ 6552-0x259e)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x10ba+ 310-0x11f0),
(0x0c9d+ 1032-0x10a2))."\x2e").substr ($milisec,(0x0027+ 805-0x0349))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x0964+ 6949-0x2487)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x14dd+ 2866-0x200e)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x1398+ 1932-0x1b24)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x14bf+ 2738-0x1f71),
(0x03f9+ 7562-0x2180))."\x2e").substr ($milisec,(0x0860+ 3712-0x16dd))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x037c+ 8723-0x258f),(0x0796+ 6975-0x22d2)).substr ($milisec,
(0x10b2+ 1241-0x1588))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0804+ 3160-0x145a)]).sprintf (
"\x25\x30\x32\x64",$time[(0x22ff+ 372-0x2472)])).sprintf ("\x25\x30\x32\x64",
$time[(0x026b+ 5534-0x1809)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x11c2+ 1322-0x16ec),(0x16fc+ 525-0x1906))."\x2e").substr ($milisec,
(0x0be6+ 4264-0x1c8b))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x14c4+ 612-0x0fbc)+$time[(0x03b0+ 8713-0x25b4)]),((0x0694+ 1303-0x0baa)+
$time[(0x128f+ 4502-0x2421)]),$time[(0x0f69+ 1002-0x1350)],$time[
(0x0779+ 4095-0x1776)],$time[(0x16af+ 2792-0x2196)],$time[(0x0f17+ 2320-0x1827)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0619+ 3257-0x12d2),(0x0ba5+ 6044-0x233e))."\x2e").substr ($milisec,
(0x02e8+ 6353-0x1bb6))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x13ba+ 4579-0x1e31)+$time[(0x18fb+ 3091-0x2509)]),($time[
(0x176a+ 897-0x1ae7)]+(0x1ab5+ 2174-0x2332)),$time[(0x1274+ 3797-0x2146)],$time[
(0x223f+ 694-0x24f3)],$time[(0x00f5+ 6044-0x1890)],$time[(0x0a97+ 5177-0x1ed0)])
);return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x1249+ 998-0x162e)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x0a81+ 2027-0x1244)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x199a+ 486-0x1b7f)))){(@arr=split ( /:/ ,$buffer,(0x1b40+ 2934-0x26b6)));(
@result=splice (@arr,(0x083d+ 5564-0x1df9),(0x0c5b+ 919-0x0ff0)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x0e8f+ 536-0x0cbf))+($microseconds/(0x1e0b+ 1712-0x20d3)))))
;return ($milliseconds);}sub Common::NXTime::getLocalTime{package Common::NXTime
;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x (0x0090+ 7587-0x1e0b))
);(my $retval=libnxh::NXLocalTime ($buffer));if (($retval!=(-
(0x0012+ 2522-0x09eb)))){(@arr=split ( /:/ ,$buffer,(0x1543+ 1857-0x1c84)));(
@result=splice (@arr,(0x0ea6+ 137-0x0f2f),(0x1b3d+ 154-0x1bce)));return (@result
);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0598+ 8338-0x2602)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x02aa+ 1555-0x08bc)))){(@arr=split ( /:/ ,$buffer,
(0x07c1+ 2545-0x11b2)));(@result=splice (@arr,(0x0ab4+ 3710-0x1932),
(0x18f0+ 643-0x1b6a)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x1fd4+ 1166-0x2462),
(0x02eb+ 2653-0x0d45))."\x2e").substr ($milisec,(0x0be9+ 725-0x0ebb))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x01cb+ 7212-0x1df5)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x1687+ 2252-0x1f52)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x0113+ 672-0x03b3)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x13bf+ 2598-0x1de5),
(0x12b0+ 205-0x137a))."\x2e").substr ($milisec,(0x151d+ 1879-0x1c71))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x0591+ 4398-0x16bf),(0x0600+ 6419-0x1f10)).substr ($milisec,
(0x031b+ 1598-0x0956))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0509+ 8475-0x2622)]).sprintf (
"\x25\x30\x32\x64",$time[(0x236f+ 850-0x26c0)])).sprintf ("\x25\x30\x32\x64",
$time[(0x0198+ 5647-0x17a7)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0d97+ 3293-0x1a74),(0x17e4+ 1790-0x1edf))."\x2e").substr ($milisec,
(0x1977+ 3468-0x2700))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x1775+ 1704-0x16b1)+$time[(0x0308+ 8820-0x2577)]),((0x1428+ 3440-0x2197)+
$time[(0x0877+ 4018-0x1825)]),$time[(0x19c7+ 162-0x1a66)],$time[
(0x181a+ 1781-0x1f0d)],$time[(0x13d6+ 1703-0x1a7c)],$time[(0x0f3b+ 1000-0x1323)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x1313+ 1532-0x190f),(0x1899+ 1804-0x1fa2))."\x2e").substr ($milisec,
(0x0a9d+ 1838-0x11c8))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x0d9b+ 1966-0x0ddd)+$time[(0x0fb9+ 444-0x1170)]),($time[
(0x08cd+ 2549-0x12be)]+(0x0708+ 3734-0x159d)),$time[(0x0d2b+ 6493-0x2685)],$time
[(0x1f4c+ 1877-0x269f)],$time[(0x01aa+ 7392-0x1e89)],$time[(0x1f02+ 1329-0x2433)
]));return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x02c6+  42-0x02ef)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";
